UID

Struct UID 

pub struct UID {
    pub id: ID,
}
Globally unique IDs that define an object’s ID in storage. Any Sui Object, that is a struct with the key ability, must have id: UID as its first field. These are globally unique in the sense that no two values of type UID are ever equal, in other words for any two values id1: UID and id2: UID, id1 != id2. This is a privileged type that can only be derived from a TxContext. UID doesn’t have the drop ability, so deleting a UID requires a call to delete.

Fields

id: ID

Implementations

Source

impl UID

pub fn move_instance( self, address: Address, module: Identifier, ) -> MoveInstance<Self>

pub fn type_(address: Address, module: Identifier) -> UIDTypeTag

Source

impl UID

pub const fn new(object_id: Address) -> Self