Module tx_context

Module tx_context 

Structs

TxContext
Information about the transaction currently being executed. This cannot be constructed by a transaction–it is a privileged object created by the VM and passed in to the entrypoint of the transaction as &mut TxContext.
TxContextTypeTag